@@ -21,11 +21,11 @@
 #include <QBuffer>
 #include <QImage>
 //Added by qt3to4:
-#include <QList>
+#include <Q3ValueList>
 
 #include <kdebug.h>
 
-#include <Picture.h>
+#include <KoPicture.h>
 
 #include "KWEFStructures.h"
 #include "KWEFBaseWorker.h"
@@ -33,7 +33,7 @@
 
 void KWEFBaseWorker::registerKWordLeader(KWEFKWordLeader* leader)
 {
-    m_kwordLeader = leader;
+    m_kwordLeader=leader;
 }
 
 //
@@ -46,7 +46,7 @@ bool KWEFBaseWorker::doAbortFile(void)
     return doCloseFile();
 }
 
-bool KWEFBaseWorker::doFullDocument(const QList<ParaData>& paraList)
+bool KWEFBaseWorker::doFullDocument (const Q3ValueList<ParaData>& paraList)
 {
     if (!doOpenTextFrameSet())
         return false;
@@ -58,12 +58,13 @@ bool KWEFBaseWorker::doFullDocument(const QList<ParaData>& paraList)
     return true;
 }
 
-bool KWEFBaseWorker::doFullAllParagraphs(const QList<ParaData>& paraList)
+bool KWEFBaseWorker::doFullAllParagraphs (const Q3ValueList<ParaData>& paraList)
 {
-    QList<ParaData>::ConstIterator it;
-    QList<ParaData>::ConstIterator end(paraList.end());
-    for (it = paraList.begin();it != end;++it) {
-        if (!doFullParagraph((*it).text, (*it).layout, (*it).formattingList))
+    Q3ValueList<ParaData>::ConstIterator it;
+	Q3ValueList<ParaData>::ConstIterator end(paraList.end());
+    for (it=paraList.begin();it!=end;++it)
+    {
+        if (!doFullParagraph((*it).text,(*it).layout,(*it).formattingList))
             return false;
     }
     return true;
@@ -74,10 +75,13 @@ bool KWEFBaseWorker::loadSubFile(const QString& fileName, QByteArray& array) con
 //   true if the file is not empty
 //   false if the file is empty or if an error occurred
 {
-    bool flag = false;
-    if (m_kwordLeader) {
-        flag = m_kwordLeader->loadSubFile(fileName, array);
-    } else {
+    bool flag=false;
+    if (m_kwordLeader)
+    {
+        flag=m_kwordLeader->loadSubFile(fileName,array);
+    }
+    else
+    {
         kWarning(30508) << "Leader is unknown! (KWEFBaseWorker::loadSubFile)";
     }
     return flag;
@@ -85,7 +89,8 @@ bool KWEFBaseWorker::loadSubFile(const QString& fileName, QByteArray& array) con
 
 QIODevice* KWEFBaseWorker::getSubFileDevice(const QString& fileName) const
 {
-    if (!m_kwordLeader) {
+    if (!m_kwordLeader)
+    {
         kWarning(30508) << "Leader is unknown! (KWEFBaseWorker::getSubFileDevice)";
         return NULL;
     }
@@ -94,42 +99,44 @@ QIODevice* KWEFBaseWorker::getSubFileDevice(const QString& fileName) const
 
 QImage KWEFBaseWorker::loadAndConvertToImage(const QString& strName, const QString& inExtension) const
 {
-    QIODevice* io = getSubFileDevice(strName);
-    if (!io) {
+    QIODevice* io=getSubFileDevice(strName);
+    if (!io)
+    {
         // NO message error, as there must be already one
         return QImage();
     }
 
-    kDebug(30508) << "Picture" << strName << " has size:" << io->size();
-
-    Picture picture;
-    if (!picture.load(io, inExtension)) { // we do not care about PictureKey
+    kDebug(30508) <<"Picture" << strName <<" has size:" << io->size();
+    
+    KoPicture picture;
+    if (!picture.load(io, inExtension)) // we do not care about KoPictureKey
+    {
         kWarning(30508) << "Could not read picture: " << strName << " (KWEFBaseWorker::loadAndConvertToImage)";
         return QImage();
     }
-
-    return picture.generateImage(picture.getOriginalSize()); // ### TODO: Picture::getOriginalSize is bad for cliparts
+    
+    return picture.generateImage(picture.getOriginalSize()); // ### TODO: KoPicture::getOriginalSize is bad for cliparts
 }
 
 bool KWEFBaseWorker::loadAndConvertToImage(const QString& strName, const QString& inExtension, const QString& outExtension, QByteArray& image) const
 {
-    Q_UNUSED(outExtension);
-    Q_UNUSED(image);
-    QImage qimage(loadAndConvertToImage(strName, inExtension));
-
-    if (qimage.isNull()) {
+    QImage qimage(loadAndConvertToImage(strName,inExtension));
+    
+    if (qimage.isNull())
+    {
         kWarning(30508) << "Could not load image (KWEFBaseWorker::loadAndConvertToImage)";
         return false;
     }
 #ifdef __GNUC__
 #warning "kde4: port it"
 #endif
-#if 0
+#if 0    
     QImageIO imageIO;
     imageIO.setImage(qimage);
 
     QBuffer buffer(&image); // A QBuffer is a QIODevice
-    if (!buffer.open(QIODevice::WriteOnly)) {
+    if (!buffer.open(QIODevice::WriteOnly))
+    {
         kWarning(30508) << "Could not open buffer! (KWEFBaseWorker::loadAndConvertToImage)";
         return false;
     }
@@ -137,7 +144,8 @@ bool KWEFBaseWorker::loadAndConvertToImage(const QString& strName, const QString
     imageIO.setIODevice(&buffer);
     imageIO.setFormat(outExtension.utf8());
 
-    if (!imageIO.write()) {
+    if (!imageIO.write())
+    {
         kWarning(30508) << "Could not write converted image! (KWEFBaseWorker::loadAndConvertToImage)";
         return false;
     }
@@ -158,13 +166,13 @@ bool KWEFBaseWorker::loadAndConvertToImage(const QString& strName, const QString
         return false;\
     }
 
-DO_FALSE_DEFINITION(doOpenFile(const QString& , const QString&))
-DO_FALSE_DEFINITION(doCloseFile(void))
-DO_FALSE_DEFINITION(doOpenDocument(void))
-DO_FALSE_DEFINITION(doCloseDocument(void))
+DO_FALSE_DEFINITION (doOpenFile (const QString& , const QString& ))
+DO_FALSE_DEFINITION (doCloseFile (void))
+DO_FALSE_DEFINITION (doOpenDocument (void))
+DO_FALSE_DEFINITION (doCloseDocument (void))
 
 // The following is not generated by the leader
-DO_FALSE_DEFINITION(doFullParagraph(const QString&, const LayoutData&, const ValueListFormatData&))
+DO_FALSE_DEFINITION (doFullParagraph(const QString&, const LayoutData&, const ValueListFormatData&))
 
 //
 // Thirdly, define all methods returning true
@@ -176,26 +184,26 @@ DO_FALSE_DEFINITION(doFullParagraph(const QString&, const LayoutData&, const Val
         return true;\
     }
 
-DO_TRUE_DEFINITION(doFullDocumentInfo(const KWEFDocumentInfo&))
-DO_TRUE_DEFINITION(doVariableSettings(const VariableSettingsData &))
-DO_TRUE_DEFINITION(doFullPaperFormat(const int, const double, const double, const int))
-DO_TRUE_DEFINITION(doFullPaperBorders(const double, const double, const double, const double))
-DO_TRUE_DEFINITION(doFullPaperFormatOther(const int, const double, const int))
-DO_TRUE_DEFINITION(doPageInfo(int, int))
-DO_TRUE_DEFINITION(doOpenHead(void))
-DO_TRUE_DEFINITION(doCloseHead(void))
-DO_TRUE_DEFINITION(doOpenBody(void))
-DO_TRUE_DEFINITION(doCloseBody(void))
-DO_TRUE_DEFINITION(doOpenStyles(void))
-DO_TRUE_DEFINITION(doCloseStyles(void))
-DO_TRUE_DEFINITION(doFullDefineStyle(LayoutData&))
-DO_TRUE_DEFINITION(doOpenSpellCheckIgnoreList(void))
-DO_TRUE_DEFINITION(doCloseSpellCheckIgnoreList(void))
-DO_TRUE_DEFINITION(doFullSpellCheckIgnoreWord(const QString&))
-DO_TRUE_DEFINITION(doHeader(const HeaderData&))
-DO_TRUE_DEFINITION(doFooter(const FooterData&))
-DO_TRUE_DEFINITION(doDeclareNonInlinedFramesets(QList<FrameAnchor>&, QList<FrameAnchor>&))
+DO_TRUE_DEFINITION (doFullDocumentInfo (const KWEFDocumentInfo&))
+DO_TRUE_DEFINITION (doVariableSettings (const VariableSettingsData &))
+DO_TRUE_DEFINITION (doFullPaperFormat (const int, const double, const double, const int))
+DO_TRUE_DEFINITION (doFullPaperBorders (const double, const double, const double, const double))
+DO_TRUE_DEFINITION (doFullPaperFormatOther ( const int, const double, const int ) )
+DO_TRUE_DEFINITION (doPageInfo(int,int))
+DO_TRUE_DEFINITION (doOpenHead (void))
+DO_TRUE_DEFINITION (doCloseHead (void))
+DO_TRUE_DEFINITION (doOpenBody (void))
+DO_TRUE_DEFINITION (doCloseBody (void))
+DO_TRUE_DEFINITION (doOpenStyles (void))
+DO_TRUE_DEFINITION (doCloseStyles (void))
+DO_TRUE_DEFINITION (doFullDefineStyle (LayoutData&))
+DO_TRUE_DEFINITION (doOpenSpellCheckIgnoreList (void))
+DO_TRUE_DEFINITION (doCloseSpellCheckIgnoreList (void))
+DO_TRUE_DEFINITION (doFullSpellCheckIgnoreWord (const QString&))
+DO_TRUE_DEFINITION (doHeader(const HeaderData&))
+DO_TRUE_DEFINITION (doFooter(const FooterData&))
+DO_TRUE_DEFINITION ( doDeclareNonInlinedFramesets( Q3ValueList<FrameAnchor>&, Q3ValueList<FrameAnchor>& ) )
 
 //  The following are not generated by the leader
-DO_TRUE_DEFINITION(doOpenTextFrameSet(void))
-DO_TRUE_DEFINITION(doCloseTextFrameSet(void))
+DO_TRUE_DEFINITION (doOpenTextFrameSet (void))
+DO_TRUE_DEFINITION (doCloseTextFrameSet (void))
