@@ -182,6 +182,19 @@ int Conversion::fillPatternStyle(int ipat)
     }
 }
 
+uint Conversion::shadingPatternToColor(int ipat)
+{
+    uint resultColor = 0xffffff, grayLevel = 0;
+    bool ok;
+
+    grayLevel = ditheringToGray(ipat, &ok);     // try to convert ipat to gray level
+
+    if(ok != true)                              // if conversion failed, return white (shouldn't happen)
+        return resultColor;
+
+    resultColor = (grayLevel << 16) | (grayLevel <<  8) | grayLevel;    // construct RGB from the same value (to create gray)
+    return resultColor;
+}
 
 int Conversion::ditheringToGray(int ipat, bool* ok)
 {
@@ -337,14 +350,15 @@ QString Conversion::setDoubleBorderAttributes(const wvWare::Word97::BRC& brc)
 //color = six-digit hexadecimal color value
 QString Conversion::setBorderAttributes(const wvWare::Word97::BRC& brc)
 {
-    kDebug(30153) << "brc.brcType = " << brc.brcType;
+    kDebug(30153) << "brc.brcType      = " << brc.brcType;
     kDebug(30153) << "brc.dptLineWidth = " << brc.dptLineWidth;
+    kDebug(30153) << "brc.cv           = " << brc.cv;
 
 
     //set the border width
     qreal w;
     if (brc.brcType < 0x40) // this is according to http://msdn.microsoft.com/en-us/library/dd907496.aspx
-        w =  brc.dptLineWidth / 8.0;
+        w = brc.dptLineWidth / 8.0;
     else
         w = brc.dptLineWidth;
 
@@ -559,3 +573,31 @@ int Conversion::fldToFieldType(const wvWare::FLD* fld)
 
     return m_fieldType;
 }
+
+qreal Conversion::twipsToInch(int twips)
+{
+    qreal inches = (qreal) twips;
+    inches = inches * 0.00069444444;
+    return inches;
+}
+
+qreal Conversion::twipsToPt(int twips)
+{
+    qreal pt = (qreal) twips;
+    pt = pt / 20.0;
+    return pt;
+}
+
+QString Conversion::rncToStartNumberingAt(int rnc) 
+{
+    switch(rnc) {
+    case 0:
+        return "document";
+    case 1:
+        return "section";
+    case 2:
+    default:
+        return "page";
+    }
+}
+
