@@ -26,6 +26,7 @@
 #include "handlers.h"
 #include "footnotes97.h"
 #include "annotations.h"
+#include "bookmark.h"
 #include "headers.h"
 #include "fonts.h"
 #include "textconverter.h"
@@ -40,7 +41,6 @@
 #include "convert.h"
 #include "zcodec.hxx"
 #include "wvlog.h"
-
 #include "ms_odraw.h"
 
 #include <gsf/gsf-input.h>
@@ -69,7 +69,7 @@ Parser9x::Position::Position( U32 cp, const PLCF<Word97::PCD>* plcfpcd ) :
 Parser9x::Parser9x( OLEStorage* storage, OLEStreamReader* wordDocument, const Word97::FIB& fib ) :
         Parser( storage, wordDocument ), m_fib( fib ), m_table( 0 ), m_data( 0 ), m_properties( 0 ),
         m_headers( 0 ), m_lists( 0 ), m_textconverter( 0 ), m_fields( 0 ), m_footnotes( 0 ), m_annotations( 0 ),
-        m_fonts( 0 ), m_drawings( 0 ), m_plcfpcd( 0 ), m_tableRowStart( 0 ), m_tableRowLength( 0 ),
+        m_fonts( 0 ), m_drawings( 0 ), m_bookmark(0), m_plcfpcd( 0 ), m_tableRowStart( 0 ), m_tableRowLength( 0 ),
         m_cellMarkFound( false ), m_remainingCells( 0 ), m_currentParagraph( new Paragraph ),
         m_remainingChars( 0 ), m_sectionNumber( 0 ), m_subDocument( None ), m_parsingMode( Default )
 {
@@ -242,6 +242,30 @@ void Parser9x::parseFootnote( const FootnoteData& data )
 #endif
 }
 
+void Parser9x::parseBookmark( const BookmarkData& data )
+{
+#ifdef WV2_DEBUG_BOOKMARK
+    wvlog << "Parser9x::parseBookmark()" << endl;
+#endif
+    if ( data.startCP == 0 ) // shouldn't happen, but well...
+        return;
+
+    saveState( data.limCP - data.startCP, Bookmark );
+    m_subDocumentHandler->bookmarkStart();
+
+
+    U32 offset = data.startCP;
+
+    parseHelper( Position( offset, m_plcfpcd ) );
+
+    m_subDocumentHandler->bookmarkEnd();
+    restoreState();
+#ifdef WV2_DEBUG_BOOKMARK
+    wvlog << "Parser9x::parseBookmark() done" << endl;
+#endif
+}
+
+
 void Parser9x::parseAnnotation( const AnnotationData& data )
 {
 #ifdef WV2_DEBUG_ANNOTATIONS
@@ -381,6 +405,9 @@ void Parser9x::init()
     if (( m_fib.ccpFtn != 0 ) || ( m_fib.ccpEdn != 0 ))
         m_footnotes = new Footnotes97( m_table, m_fib );
 
+    if (( m_fib.fcPlcfbkf != 0 ) || ( m_fib.fcPlcfbkl != 0 ))
+        m_bookmark = new Bookmarks( m_table, m_fib );
+
     if ( m_fib.ccpAtn != 0 ) {
         m_annotations = new Annotations( m_table, m_fib );
     }
@@ -666,6 +693,9 @@ void Parser9x::processParagraph( U32 fc )
         if ( props->pap().fTtp ) {
             // Restore the table properties of this row
             Word97::TAP* tap = m_properties->fullSavedTap( fc, m_data );
+#ifdef WV2_DEBUG_TABLES
+            tap->dump();
+#endif
             m_properties->applyClxGrpprl( m_plcfpcd->at( m_currentParagraph->back().m_position.piece ).current(),
                                           m_fib.fcClx, tap, m_properties->styleByIndex( props->pap().istd ) );
 
@@ -757,6 +787,14 @@ void Parser9x::processChunk( const Chunk& chunk, SharedPtr<const Word97::CHP> ch
 #ifdef WV2_DEBUG_FOOTNOTES
             wvlog << "nextFtn=" << nextFtn << " nextEnd=" << nextEnd << " disruption="
                     << disruption << " length=" << length << endl;
+#endif
+        } else if ( m_bookmark ) {
+            U32 nextBkf = m_bookmark->nextBookmarkStart();
+            U32 nextBkl = m_bookmark->nextBookmarkEnd();
+            disruption = nextBkf < nextBkl ? nextBkf : nextBkl;
+#ifdef WV2_DEBUG_BOOKMARK
+            wvlog << "nextBkf=" << nextBkf << " nextBkl=" << nextBkl << " disruption="
+                    << disruption << " length=" << length << endl;
 #endif
         }
         U32 startCP = currentStart + chunk.m_position.offset + index;
@@ -765,22 +803,41 @@ void Parser9x::processChunk( const Chunk& chunk, SharedPtr<const Word97::CHP> ch
 #ifdef WV2_DEBUG_FOOTNOTES
             wvlog << "startCP=" << startCP << " len=" << length << " disruption=" << disruption << endl;
 #endif
+
+#ifdef WV2_DEBUG_BOOKMARK
+            wvlog << "startCP=" << startCP << " len=" << length << " disruption=" << disruption << endl;
+#endif
             U32 disLen = disruption - startCP;
             if ( disLen != 0 )
                 processRun( chunk, chp, disLen, index, currentStart );
             length -= disLen;
             index += disLen;
-            m_customFootnote = chunk.m_text.substr(index, length);
-            processFootnote( m_customFootnote, disruption, chp, length );
+
+            if ( m_footnotes ) {
+                m_customFootnote = chunk.m_text.substr(index, length);
+                emitFootnote( m_customFootnote, disruption, chp, length );
+                m_customFootnote = "";
+            } else if ( m_bookmark ) {
+                m_bookmarkText = chunk.m_text.substr(index, length);
+                emitBookmark( m_bookmarkText, disruption, chp, length );
+                m_bookmarkText = "";
+            }
             index+=length;
             length=0;
-            m_customFootnote = "";
         }
         else {
+
             // common case, no disruption at all (or the end of a disrupted chunk)
             //In case of custom footnotes do not add label to footnote body.
-            if (m_customFootnote.find(chunk.m_text.substr(index, length), 0) != 0)
-                processRun( chunk, chp, length, index, currentStart );
+            if ( m_footnotes ) {
+                if (m_customFootnote.find(chunk.m_text.substr(index, length), 0) != 0)
+                    processRun( chunk, chp, length, index, currentStart );
+            } else if ( m_bookmark ) {
+                if (m_bookmarkText.find(chunk.m_text.substr(index, length), 0) != 0) {
+                    processRun( chunk, chp, length, index, currentStart );
+                }
+            }
+
             break;   // should be faster than messing with length...
         }
     }
@@ -792,7 +849,7 @@ void Parser9x::processRun( const Chunk& chunk, SharedPtr<const Word97::CHP> chp,
     if ( chp->fSpec ) {
         U32 i = 0;
         while ( i < length ) {
-            processSpecialCharacter( chunk.m_text[ index + i ], currentStart + chunk.m_position.offset + index + i, chp );
+            emitSpecialCharacter( chunk.m_text[ index + i ], currentStart + chunk.m_position.offset + index + i, chp );
             ++i;
         }
     }
@@ -802,7 +859,7 @@ void Parser9x::processRun( const Chunk& chunk, SharedPtr<const Word97::CHP> chp,
     }
 }
 
-void Parser9x::processSpecialCharacter( UChar character, U32 globalCP, SharedPtr<const Word97::CHP> chp )
+void Parser9x::emitSpecialCharacter( UChar character, U32 globalCP, SharedPtr<const Word97::CHP> chp )
 {
     switch( character.unicode() ) {
         // Is it one of the "simple" special characters?
@@ -844,7 +901,7 @@ void Parser9x::processSpecialCharacter( UChar character, U32 globalCP, SharedPtr
         if ( m_subDocument == Footnote || m_subDocument == Endnote )
             m_textHandler->footnoteAutoNumber( chp );
         else
-            processFootnote( UString(character), globalCP, chp);
+            emitFootnote( UString(character), globalCP, chp);
         break;
     case TextHandler::FieldBegin:
         {
@@ -869,7 +926,7 @@ void Parser9x::processSpecialCharacter( UChar character, U32 globalCP, SharedPtr
         }
     case TextHandler::AnnotationRef:
         {
-            processAnnotation(UString(character), globalCP, chp);
+            emitAnnotation(UString(character), globalCP, chp);
         }
     case TextHandler::FieldEscapeChar:
             wvlog << "Found an escape character ++++++++++++++++++++?" << endl;
@@ -881,7 +938,7 @@ void Parser9x::processSpecialCharacter( UChar character, U32 globalCP, SharedPtr
 }
 }
 
-void Parser9x::processFootnote( UString characters, U32 globalCP, SharedPtr<const Word97::CHP> chp, U32 /* length */ )
+void Parser9x::emitFootnote( UString characters, U32 globalCP, SharedPtr<const Word97::CHP> chp, U32 /* length */ )
 {
     if ( !m_footnotes ) {
         wvlog << "Bug: Found a footnote, but m_footnotes == 0!" << endl;
@@ -896,7 +953,25 @@ void Parser9x::processFootnote( UString characters, U32 globalCP, SharedPtr<cons
         m_textHandler->footnoteFound( data.type, characters, chp, make_functor( *this, &Parser9x::parseFootnote, data ));
 }
 
-void Parser9x::processAnnotation( UString characters, U32 globalCP, SharedPtr<const Word97::CHP> chp, U32 /* length */ )
+void Parser9x::emitBookmark( UString characters, U32 globalCP, SharedPtr<const Word97::CHP> chp, U32 length )
+{
+    if ( !m_bookmark ) {
+        wvlog << "Bug: Found a bookmark, but m_bookmark == 0!" << endl;
+        return;
+    }
+#ifdef WV2_DEBUG_BOOKMARK
+    wvlog << "Bookmark found: CP=" << globalCP << endl;
+#endif
+    bool ok;
+    BookmarkData data( m_bookmark->bookmark( globalCP, ok ) );
+
+    if (ok) {
+        // We introduce the name of the bookmark here with data.name
+        m_textHandler->bookmarkFound( characters, data.name, chp, make_functor( *this, &Parser9x::parseBookmark, data ));
+    }
+}
+
+void Parser9x::emitAnnotation( UString characters, U32 globalCP, SharedPtr<const Word97::CHP> chp, U32 /* length */ )
 {
     for (int i = 0; i < characters.length(); ++i) {
         wvlog << characters[i].unicode();
@@ -1050,6 +1125,9 @@ void Parser9x::parsePictureEscher( const PictureData& data, OLEStreamReader* str
             << "\n  endOfPicf = " << endOfPicf << endl;
 #endif
 
+    // which BLIP to display in the picture shape
+    U32 pib = 0;
+
     OfficeArtProperties artProps;
     memset(&artProps, 0, sizeof(artProps));
     artProps.width = 100.0f;                    // default is 100% width
@@ -1087,18 +1165,19 @@ void Parser9x::parsePictureEscher( const PictureData& data, OLEStreamReader* str
 #ifdef WV2_DEBUG_PICTURES
                 wvlog << "  starting new inner record: " << endl;
                 h.dump();
-                wvlog << h.getRecordType() << endl;
+                wvlog << h.getRecordType().c_str() << endl;
 #endif
                 //process record
                 if (h.isAtom()) {
                     U8 alreadyProcessed = 0;
-
-                    if (h.getRecordType() == "msofbtSp") {          // is it 'OfficeArtFSP'? (MS-ODRAW, page 80/621)
+                    // is it 'OfficeArtFSP'? (MS-ODRAW, page 80/621)
+                    if (h.getRecordType() == "msofbtSp") {
 
                     }
-
-                    if (h.getRecordType() == "msofbtOPT" || h.getRecordType() == "msofbtTerOPT") { // is it 'OfficeArtFOPT' or 'OfficeArtTertiaryFOPT'?
-                        parseOfficeArtFOPT(stream, h.recordSize(), &artProps);
+                    // is it 'OfficeArtFOPT' or 'OfficeArtTertiaryFOPT'?
+                    if (h.getRecordType() == "msofbtOPT" ||
+                        h.getRecordType() == "msofbtTerOPT") {
+                        parseOfficeArtFOPT(stream, h.recordSize(), &artProps, &pib);
                         alreadyProcessed = 1;
                     }
 
@@ -1151,13 +1230,13 @@ void Parser9x::parsePictureEscher( const PictureData& data, OLEStreamReader* str
                     z.SetBreak(blip.compressedImageSize());
                     std::vector<U8> outBuffer;
                     int err = z.Decompress( *stream, &outBuffer );
-#ifdef WV2_DEBUG_PICTURES
                     wvlog << "  err=" << err << endl;
+#ifdef WV2_DEBUG_PICTURES
                     wvlog << "  outBuffer size = " << outBuffer.size() << endl;
 #endif
                     z.EndCompression(&outBuffer);
                     //pass vector to escherData instead of OLEImageReader
-                    m_pictureHandler->escherData(outBuffer, data.picf, fbse.getBlipType());
+                    m_pictureHandler->escherData(outBuffer, data.picf, fbse.getBlipType(), pib);
                 }
                 //normal data, just create an OLEImageReader to be read
                 else
@@ -1165,7 +1244,7 @@ void Parser9x::parsePictureEscher( const PictureData& data, OLEStreamReader* str
                     int start = stream->tell();
                     int limit = endOfPicf; //TODO is it possible that it wouldn't go all the way to the end?
                     OLEImageReader reader( *stream, start, limit);
-                    m_pictureHandler->escherData(reader, data.picf, fbse.getBlipType());
+                    m_pictureHandler->escherData(reader, data.picf, fbse.getBlipType(), pib);
                     //we've read the data in OLEImageReader, so advance stream to the
                     //end of OLEImageReader
                     stream->seek( endOfPicf, G_SEEK_SET );
@@ -1190,7 +1269,7 @@ void Parser9x::parsePictureEscher( const PictureData& data, OLEStreamReader* str
     } while (stream->tell() != endOfPicf); //end of record
 }
 
-void Parser9x::parseOfficeArtFOPT(OLEStreamReader* stream, int dataSize, OfficeArtProperties *artProperties)
+void Parser9x::parseOfficeArtFOPT(OLEStreamReader* stream, int dataSize, OfficeArtProperties *artProperties, U32* pib)
 {
 #ifdef WV2_DEBUG_PICTURES
   wvlog << "parseOfficeArtFOPT - processing bytes: " << dataSize << endl;
@@ -1208,12 +1287,15 @@ void Parser9x::parseOfficeArtFOPT(OLEStreamReader* stream, int dataSize, OfficeA
       fComplex  = (opid >> 15) & 0x01;          // get bit 15
       opidOpid  = opid & 0x3fff;                // leave only lowest 14 bits
 
+#ifdef WV2_DEBUG_PICTURES
+      wvlog << "opidOpid" <<  hex << (int) opidOpid << dec << endl;
+#endif
+
       switch (opidOpid) {
           case opidGroupShapeProps:
               if ((op & ((1<<11) | (1<<27))) == ((1<<11) | (1<<27))) {  // if true, it's a horizontal rule
                   artProperties->shapeType = msosptLine;
               }
-
               break;
 
           case opidPctHR:
@@ -1221,7 +1303,7 @@ void Parser9x::parseOfficeArtFOPT(OLEStreamReader* stream, int dataSize, OfficeA
               break;
 
           case opidAlignHR:
-              artProperties->align = (wvWare::HRALIGN) op;
+              artProperties->align = (wvWare::H_ALIGN) op;
               break;
 
           case opidDxHeightHR:
@@ -1232,7 +1314,14 @@ void Parser9x::parseOfficeArtFOPT(OLEStreamReader* stream, int dataSize, OfficeA
               artProperties->color.r = (op      ) & 0xff;
               artProperties->color.g = (op >>  8) & 0xff;
               artProperties->color.b = (op >> 16) & 0xff;
+              break;
 
+          case opidPib:
+#ifdef WV2_DEBUG_PICTURES
+	      wvlog << "parseOfficeArtFOPT - BLIP to display: " << (U32) op << endl;
+#endif
+	      *pib = (U32) op;
+	      artProperties->pib = 1;
               break;
 
           default:
