@@ -7,24 +7,22 @@
  **
  ** This file is part of the KD Chart library.
  **
- ** This file may be distributed and/or modified under the terms of the
- ** GNU General Public License version 2 as published by the Free Software
- ** Foundation and appearing in the file LICENSE.GPL included in the
- ** packaging of this file.
- **
- ** Licensees holding valid commercial KD Chart licenses may use this file in
- ** accordance with the KD Chart Commercial License Agreement provided with
- ** the Software.
- **
+ ** This file may be used under the terms of the GNU General Public
+ ** License versions 2.0 or 3.0 as published by the Free Software
+ ** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
+ ** included in the packaging of this file.  Alternatively you may (at
+ ** your option) use any later version of the GNU General Public
+ ** License if such license has been publicly approved by
+ ** Klarälvdalens Datakonsult AB (or its successors, if any).
+ ** 
+ ** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
+ ** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
+ ** A PARTICULAR PURPOSE. Klarälvdalens Datakonsult AB reserves all rights
+ ** not expressly granted herein.
+ ** 
  ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
  ** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  **
- ** See http://www.kdab.net/kdchart for
- **   information about KD Chart Commercial License Agreements.
- **
- ** Contact info@kdab.net if any conditions of this
- ** licensing are not clear to you.
- **
  **********************************************************************/
 
 #ifndef KDCHARTLINEDIAGRAM_H
@@ -43,7 +41,7 @@ namespace KDChart {
 
 /**
  * @brief LineDiagram defines a common line diagram.
- * 
+ *
  * It provides different subtypes which are set using \a setType.
  */
 class KDCHART_EXPORT LineDiagram : public AbstractCartesianDiagram
@@ -60,7 +58,7 @@ public:
     class LineDiagramType;
     friend class LineDiagramType;
 
-    LineDiagram( QWidget* parent = 0, CartesianCoordinatePlane* plane = 0 );
+    explicit LineDiagram( QWidget* parent = 0, CartesianCoordinatePlane* plane = 0 );
     virtual ~LineDiagram();
 
     virtual LineDiagram * clone() const;
@@ -80,6 +78,16 @@ public:
     void setType( const LineType type );
     LineType type() const;
 
+    /** If centerDataPoints() is true, all data points are moved by an
+     * offset of 0.5 to the right. This is useful in conjunction with
+     * bar diagrams, since data points are then centered just like bars.
+     *
+     * \sa centerDataPoints()
+     */
+    void setCenterDataPoints( bool center );
+    /** @return option set by setCenterDataPoints() */
+    bool centerDataPoints() const;
+
     void setLineAttributes( const LineAttributes & a );
     void setLineAttributes( int column, const LineAttributes & a );
     void setLineAttributes( const QModelIndex & index, const LineAttributes & a );
@@ -105,11 +113,19 @@ public:
                                     const ValueTrackerAttributes & a );
     ValueTrackerAttributes valueTrackerAttributes( const QModelIndex & index ) const;
 
+#if QT_VERSION < 0x040400 || defined(Q_COMPILER_MANGLES_RETURN_TYPE)
     // implement AbstractCartesianDiagram
     /* reimpl */
     const int numberOfAbscissaSegments () const;
     /* reimpl */
     const int numberOfOrdinateSegments () const;
+#else
+    // implement AbstractCartesianDiagram
+    /* reimpl */
+    int numberOfAbscissaSegments () const;
+    /* reimpl */
+    int numberOfOrdinateSegments () const;
+#endif
 
 protected:
     void paint ( PaintContext* paintContext );
