@@ -31,7 +31,6 @@
 #include <klocale.h>
 
 #include <QHash>
-#include <QLineEdit>
 #include <QMap>
 
 namespace KPlato
@@ -604,6 +603,15 @@ NodeDeleteCmd::NodeDeleteCmd( Node *node, const QString& name )
     for ( int i = lst.count(); i > 0; --i ) {
         m_cmd->addCommand( new NodeDeleteCmd( lst[ i - 1 ] ) );
     }
+    if ( node->runningAccount() ) {
+        m_cmd->addCommand( new NodeModifyRunningAccountCmd( *node, node->runningAccount(), 0 ) );
+    }
+    if ( node->startupAccount() ) {
+        m_cmd->addCommand( new NodeModifyRunningAccountCmd( *node, node->startupAccount(), 0 ) );
+    }
+    if ( node->shutdownAccount() ) {
+        m_cmd->addCommand( new NodeModifyRunningAccountCmd( *node, node->shutdownAccount(), 0 ) );
+    }
 
 }
 NodeDeleteCmd::~NodeDeleteCmd()
@@ -839,7 +847,9 @@ NodeModifyConstraintStartTimeCmd::NodeModifyConstraintStartTimeCmd( Node &node,
         newTime( dt ),
         oldTime( node.constraintStartTime() )
 {
-    m_spec = static_cast<Project*>( node.projectNode() )->timeSpec();
+    if ( node.projectNode() ) {
+        m_spec = static_cast<Project*>( node.projectNode() )->timeSpec();
+    }
 }
 void NodeModifyConstraintStartTimeCmd::execute()
 {
@@ -858,10 +868,9 @@ NodeModifyConstraintEndTimeCmd::NodeModifyConstraintEndTimeCmd( Node &node, cons
         newTime( dt ),
         oldTime( node.constraintEndTime() )
 {
-    m_spec = static_cast<Project*>( node.projectNode() )->timeSpec();
-/*    foreach ( Schedule * s, node.schedules() ) {
-        addSchScheduled( s );
-    }*/
+    if ( node.projectNode() ) {
+        m_spec = static_cast<Project*>( node.projectNode() )->timeSpec();
+    }
 }
 void NodeModifyConstraintEndTimeCmd::execute()
 {
@@ -1297,17 +1306,17 @@ void RemoveResourceRequestCmd::unexecute()
 
 }
 
-ModifyEstimateCmd::ModifyEstimateCmd( Node &node, Duration oldvalue, Duration newvalue, const QString& name )
-        : NamedCommand( name ),
-        m_estimate( node.estimate() ),
-        m_oldvalue( oldvalue ),
-        m_newvalue( newvalue ),
-        m_cmd( 0 )
+ModifyEstimateCmd::ModifyEstimateCmd( Node &node, double oldvalue, double newvalue, const QString& name )
+    : NamedCommand( name ),
+    m_estimate( node.estimate() ),
+    m_oldvalue( oldvalue ),
+    m_newvalue( newvalue ),
+    m_cmd( 0 )
 {
 /*    foreach ( Schedule * s, node.schedules() ) {
         addSchScheduled( s );
     }*/
-    if ( newvalue == Duration::zeroDuration ) {
+    if ( newvalue == 0.0 ) {
         // Milestones can't have resources, so remove resource requests
         ResourceRequestCollection *rc = node.requests();
         if ( rc ) {
@@ -1324,7 +1333,7 @@ ModifyEstimateCmd::~ModifyEstimateCmd()
 }
 void ModifyEstimateCmd::execute()
 {
-    m_estimate->set( m_newvalue );
+    m_estimate->setExpectedEstimate( m_newvalue );
 //    setSchScheduled( false );
     if ( m_cmd ) {
         m_cmd->execute();
@@ -1333,7 +1342,7 @@ void ModifyEstimateCmd::execute()
 }
 void ModifyEstimateCmd::unexecute()
 {
-    m_estimate->set( m_oldvalue );
+    m_estimate->setExpectedEstimate( m_oldvalue );
     if ( m_cmd ) {
         m_cmd->unexecute();
     }
@@ -1413,6 +1422,22 @@ void ModifyEstimateTypeCmd::unexecute()
 
 }
 
+ModifyEstimateCalendarCmd::ModifyEstimateCalendarCmd( Node &node, Calendar *oldvalue, Calendar *newvalue, const QString& name )
+    : NamedCommand( name ),
+        m_estimate( node.estimate() ),
+        m_oldvalue( oldvalue ),
+        m_newvalue( newvalue )
+{
+}
+void ModifyEstimateCalendarCmd::execute()
+{
+    m_estimate->setCalendar( m_newvalue );
+}
+void ModifyEstimateCalendarCmd::unexecute()
+{
+    m_estimate->setCalendar( m_oldvalue );
+}
+
 ModifyEstimateUnitCmd::ModifyEstimateUnitCmd( Node &node, Duration::Unit oldvalue, Duration::Unit newvalue, const QString& name )
         : NamedCommand( name ),
         m_estimate( node.estimate() ),
@@ -1422,12 +1447,12 @@ ModifyEstimateUnitCmd::ModifyEstimateUnitCmd( Node &node, Duration::Unit oldvalu
 }
 void ModifyEstimateUnitCmd::execute()
 {
-    m_estimate->setDisplayUnit( m_newvalue );
+    m_estimate->setUnit( m_newvalue );
 
 }
 void ModifyEstimateUnitCmd::unexecute()
 {
-    m_estimate->setDisplayUnit( m_oldvalue );
+    m_estimate->setUnit( m_oldvalue );
 }
 
 EstimateModifyRiskCmd::EstimateModifyRiskCmd( Node &node, int oldvalue, int newvalue, const QString& name )
@@ -1602,6 +1627,28 @@ void RemoveResourceCmd::unexecute()
     setSchScheduled();
 }
 
+MoveResourceCmd::MoveResourceCmd( ResourceGroup *group, Resource *resource, const QString& name )
+    : NamedCommand( name ),
+    m_project( *(group->project()) ),
+    m_resource( resource ),
+    m_oldvalue( resource->parentGroup() ),
+    m_newvalue( group )
+{
+    foreach ( ResourceRequest * r, resource->requests() ) {
+        cmd.addCommand( new RemoveResourceRequestCmd( r->parent(), r ) );
+    }
+}
+void MoveResourceCmd::execute()
+{
+    cmd.execute();
+    m_project.moveResource( m_newvalue, m_resource );
+}
+void MoveResourceCmd::unexecute()
+{
+    m_project.moveResource( m_oldvalue, m_resource );
+    cmd.unexecute();
+}
+
 ModifyResourceNameCmd::ModifyResourceNameCmd( Resource *resource, const QString& value, const QString& name )
         : NamedCommand( name ),
         m_resource( resource ),
@@ -1953,15 +2000,95 @@ ModifyCompletionEntrymodeCmd::ModifyCompletionEntrymodeCmd( Completion &completi
 void ModifyCompletionEntrymodeCmd::execute()
 {
     m_completion.setEntrymode( newvalue );
-
-
 }
 void ModifyCompletionEntrymodeCmd::unexecute()
 {
     m_completion.setEntrymode( oldvalue );
+}
 
+ModifyCompletionPercentFinishedCmd::ModifyCompletionPercentFinishedCmd( Completion &completion, const QDate &date, int value, const QString& name )
+    : NamedCommand( name ),
+    m_completion( completion ),
+    m_date( date ),
+    m_newvalue( value ),
+    m_oldvalue( completion.percentFinished( date ) )
+{
+    if ( ! completion.entries().contains( date ) ) {
+        Completion::Entry *e = new Completion::Entry();
+        Completion::Entry *latest = completion.entry( completion.entryDate() );
+        if ( latest ) {
+            *e = *latest;
+        }
+        cmd.addCommand( new AddCompletionEntryCmd( completion, date, e ) );
+    }
 
 }
+void ModifyCompletionPercentFinishedCmd::execute()
+{
+    cmd.execute();
+    m_completion.setPercentFinished( m_date, m_newvalue );
+}
+void ModifyCompletionPercentFinishedCmd::unexecute()
+{
+    m_completion.setPercentFinished( m_date, m_oldvalue );
+    cmd.unexecute();
+}
+
+ModifyCompletionRemainingEffortCmd::ModifyCompletionRemainingEffortCmd( Completion &completion, const QDate &date, const Duration &value, const QString &name )
+    : NamedCommand( name ),
+    m_completion( completion ),
+    m_date( date ),
+    m_newvalue( value ),
+    m_oldvalue( completion.remainingEffort( date ) )
+{
+    if ( ! completion.entries().contains( date ) ) {
+        Completion::Entry *e = new Completion::Entry();
+        Completion::Entry *latest = completion.entry( completion.entryDate() );
+        if ( latest ) {
+            *e = *latest;
+        }
+        cmd.addCommand( new AddCompletionEntryCmd( completion, date, e ) );
+    }
+
+}
+void ModifyCompletionRemainingEffortCmd::execute()
+{
+    cmd.execute();
+    m_completion.setRemainingEffort( m_date, m_newvalue );
+}
+void ModifyCompletionRemainingEffortCmd::unexecute()
+{
+    m_completion.setRemainingEffort( m_date, m_oldvalue );
+    cmd.unexecute();
+}
+
+ModifyCompletionActualEffortCmd::ModifyCompletionActualEffortCmd( Completion &completion, const QDate &date, const Duration &value, const QString &name )
+    : NamedCommand( name ),
+    m_completion( completion ),
+    m_date( date ),
+    m_newvalue( value ),
+    m_oldvalue( completion.actualEffort( date ) )
+{
+    if ( ! completion.entries().contains( date ) ) {
+        Completion::Entry *e = new Completion::Entry();
+        Completion::Entry *latest = completion.entry( completion.entryDate() );
+        if ( latest ) {
+            *e = *latest;
+        }
+        cmd.addCommand( new AddCompletionEntryCmd( completion, date, e ) );
+    }
+
+}
+void ModifyCompletionActualEffortCmd::execute()
+{
+    cmd.execute();
+    m_completion.setActualEffort( m_date, m_newvalue );
+}
+void ModifyCompletionActualEffortCmd::unexecute()
+{
+    m_completion.setActualEffort( m_date, m_oldvalue );
+    cmd.unexecute();
+}
 
 ModifyCompletionStartedCmd::ModifyCompletionStartedCmd( Completion &completion, bool value, const QString& name )
         : NamedCommand( name ),
@@ -2609,16 +2736,21 @@ DeleteScheduleManagerCmd::DeleteScheduleManagerCmd( Project &node, ScheduleManag
     : AddScheduleManagerCmd( node, sm, name )
 {
     m_mine = false;
+    foreach ( ScheduleManager *s, sm->children() ) {
+        cmd.addCommand( new DeleteScheduleManagerCmd( node, s ) );
+    }
 }
 
 void DeleteScheduleManagerCmd::execute()
 {
+    cmd.execute();
     AddScheduleManagerCmd::unexecute();
 }
 
 void DeleteScheduleManagerCmd::unexecute()
 {
     AddScheduleManagerCmd::execute();
+    cmd.unexecute();
 }
 
 ModifyScheduleManagerNameCmd::ModifyScheduleManagerNameCmd( ScheduleManager &sm, const QString& value, const QString& name )
@@ -2693,6 +2825,24 @@ void ModifyScheduleManagerCalculateAllCmd::unexecute()
     m_sm.setCalculateAll( oldvalue );
 }
 
+ModifyScheduleManagerSchedulingDirectionCmd::ModifyScheduleManagerSchedulingDirectionCmd( ScheduleManager &sm, bool value, const QString& name )
+    : NamedCommand( name ),
+    m_sm( sm ),
+    oldvalue( sm.schedulingDirection() ),
+    newvalue( value )
+{
+}
+
+void ModifyScheduleManagerSchedulingDirectionCmd::execute()
+{
+    m_sm.setSchedulingDirection( newvalue );
+}
+
+void ModifyScheduleManagerSchedulingDirectionCmd::unexecute()
+{
+    m_sm.setSchedulingDirection( oldvalue );
+}
+
 CalculateScheduleCmd::CalculateScheduleCmd( Project &node, ScheduleManager &sm, const QString& name )
     : NamedCommand( name ),
     m_node( node ),
@@ -2729,6 +2879,39 @@ void CalculateScheduleCmd::unexecute()
     m_sm.setPessimistic( m_oldpessimistic );
 }
 
+//------------------------
+BaselineScheduleCmd::BaselineScheduleCmd( ScheduleManager &sm, const QString& name )
+    : NamedCommand( name ),
+    m_sm( sm )
+{
+}
+
+void BaselineScheduleCmd::execute()
+{
+    m_sm.setBaselined( true );
+}
+
+void BaselineScheduleCmd::unexecute()
+{
+    m_sm.setBaselined( false );
+}
+
+ResetBaselineScheduleCmd::ResetBaselineScheduleCmd( ScheduleManager &sm, const QString& name )
+    : NamedCommand( name ),
+    m_sm( sm )
+{
+}
+
+void ResetBaselineScheduleCmd::execute()
+{
+    m_sm.setBaselined( false );
+}
+
+void ResetBaselineScheduleCmd::unexecute()
+{
+    m_sm.setBaselined( true );
+}
+
 //------------------------
 ModifyStandardWorktimeYearCmd::ModifyStandardWorktimeYearCmd( StandardWorktime *wt, double oldvalue, double newvalue, const QString& name )
         : NamedCommand( name ),
@@ -2927,5 +3110,22 @@ void DocumentModifySendAsCmd::unexecute()
     m_doc->setSendAs( m_oldvalue );
 }
 
+//----------------
+WBSDefinitionModifyCmd::WBSDefinitionModifyCmd( Project &project, const WBSDefinition value, const QString& name )
+    : NamedCommand( name ),
+    m_project( project )
+{
+    m_newvalue = value;
+    m_oldvalue = m_project.wbsDefinition();
+}
+void WBSDefinitionModifyCmd::execute()
+{
+    m_project.setWbsDefinition( m_newvalue );
+}
+void WBSDefinitionModifyCmd::unexecute()
+{
+    m_project.setWbsDefinition( m_oldvalue );
+}
+
 
 }  //KPlato namespace
