@@ -23,7 +23,7 @@
 #include "KPrSoundEventActionWidget.h"
 
 KPrSoundEventActionFactory::KPrSoundEventActionFactory()
-: KoEventActionFactory( KPrSoundEventActionId, "sound" )
+: KoEventActionFactoryBase( KPrSoundEventActionId, "sound" )
 {
 }
 
@@ -36,7 +36,7 @@ KoEventAction * KPrSoundEventActionFactory::createEventAction()
     return new KPrSoundEventAction();
 }
 
-KoEventActionWidget * KPrSoundEventActionFactory::createOptionWidget()
+QWidget *KPrSoundEventActionFactory::createOptionWidget()
 {
     return new KPrSoundEventActionWidget();
 }
