@@ -21,6 +21,8 @@
 #include "kis_types.h"
 #include "kis_effect_mask.h"
 
+#include "kis_node_filter_interface.h"
+
 class KisFilterConfiguration;
 
 /**
@@ -30,7 +32,7 @@ class KisFilterConfiguration;
    adjustment layers work on all layers below it in its layer group.
 */
 
-class KRITAIMAGE_EXPORT KisFilterMask : public KisEffectMask
+class KRITAIMAGE_EXPORT KisFilterMask : public KisEffectMask, public KisNodeFilterInterface
 {
     Q_OBJECT
 
@@ -43,20 +45,26 @@ public:
 
     virtual ~KisFilterMask();
 
-    KisNodeSP clone()
-    {
+    KisNodeSP clone() const {
         return KisNodeSP(new KisFilterMask(*this));
     }
 
+    bool accept(KisNodeVisitor &v);
 
-    KisFilterMask( const KisFilterMask& rhs );
+    KisFilterMask(const KisFilterMask& rhs);
 
-    bool allowAsChild( KisNodeSP );
+    bool allowAsChild(KisNodeSP) const;
 
     KisFilterConfiguration * filter() const;
     void setFilter(KisFilterConfiguration * filterConfig);
 
-    void apply( KisPaintDeviceSP projection, const QRect & rc ) const;
+    void apply(KisPaintDeviceSP projection, const QRect & rc) const;
+
+    using KisNode::setDirty;
+    virtual void setDirty();
+
+    virtual QRect adjustedDirtyRect( const QRect& _rect ) const;
+    virtual QRect neededRect( const QRect& _rect ) const;
 
 private:
 
