@@ -24,9 +24,9 @@
 #include "KoToolFactory.h"
 #include "kis_tool_bezier.h"
 
-class KisToolBezierPaint : public KisToolBezier {
+class KisToolBezierPaint : public KisToolBezier
+{
 
-    typedef KisToolBezier super;
     Q_OBJECT
 
 public:
@@ -34,8 +34,6 @@ public:
     virtual ~KisToolBezierPaint();
 
     virtual void setup(KActionCollection *collection);
-    virtual enumToolType toolType() { return TOOL_SHAPE; }
-    virtual quint32 priority() { return 7; }
 
 protected:
 
@@ -43,19 +41,19 @@ protected:
 
 };
 
-class KisToolBezierPaintFactory : public KoToolFactory {
+class KisToolBezierPaintFactory : public KoToolFactory
+{
 
 public:
     KisToolBezierPaintFactory(QObject *parent, const QStringList&)
-        : KoToolFactory(parent, "KisToolBezierPaint", i18n( "Paint with curves" ))
-        {
-            setToolTip(i18n("Draw cubic beziers. Keep Alt, Control or Shift pressed for options. Return or double-click to finish."));
-            setToolType(TOOL_TYPE_SHAPE);
-            setPriority(0);
-            setIcon("tool_bezier_paint");
-        };
+            : KoToolFactory(parent, "KisToolBezierPaint", i18n("Paint with curves")) {
+        setToolTip(i18n("Draw cubic Beziers. Keep Alt, Control or Shift pressed for options. Return or double-click to finish."));
+        setToolType(TOOL_TYPE_SHAPE);
+        setPriority(7);
+        setIcon("tool_bezier_paint");
+    };
 
-    virtual ~KisToolBezierPaintFactory(){}
+    virtual ~KisToolBezierPaintFactory() {}
 
     virtual KoTool * createTool(KoCanvasBase *canvas) {
         return new KisToolBezierPaint(canvas);
