@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
- * Copyright (C) 2006 Thomas Zander <zander@kde.org>
+ * Copyright (C) 2006, 2009 Thomas Zander <zander@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -46,8 +46,10 @@ public:
      * Constructor
      * @param shape the shape that displays the content, containing size/position
      * @param parent the parent frameset
+     * @param pageNumber the page number is normally -1, only set when loading page anchored frames to the
+     *      page where the frame should be positioned
      */
-    KWFrame(KoShape *shape, KWFrameSet *parent);
+    KWFrame(KoShape *shape, KWFrameSet *parent, int pageNumber = -1);
     virtual ~KWFrame();
 
     /**
@@ -164,6 +166,13 @@ public:
      */
     virtual void setFrameSet(KWFrameSet *newFrameSet);
 
+    void clearLoadingData() {
+        m_anchoredPageNumber = -1;
+    }
+    int loadingPageNumber() const {
+        return m_anchoredPageNumber;
+    }
+
     /**
      * States if this frame is a copy of the previous one.
      * If this frame is a copy, then this frame is drawn with the same content as the
@@ -172,35 +181,23 @@ public:
      */
     bool isCopy() const;
 
-    /**
-     * Sets if this frame is a copy of the previous one.
-     * After this call this frame is drawn with the same content as the previous frame in this frameset.
-     */
-    void makeCopyFrame();
-
     /**
      * Copy all the settings from the parameter frame and apply them to this frame.
      * @param frame the frame to use as original
      */
-    virtual void copySettings(const KWFrame *frame);
+    void copySettings(const KWFrame *frame);
 
     /**
      * Save the frame as ODF
      * @param context the context for saving.
      */
-    void saveOdf(KoShapeSavingContext & context);
+    void saveOdf(KoShapeSavingContext &context);
 
     KWOutlineShape *outlineShape() const {
         return m_outline;
     }
     void setOutlineShape(KWOutlineShape *outline);
 
-    void attachAnchor(KoTextAnchor *anchor);
-    KoTextAnchor *getAnchor();
-protected:
-    /// replace the current set shape with the argument one.
-    void setShape(KoShape *shape);
-
 private:
     KoShape *m_shape;
     KWord::FrameBehavior m_frameBehavior;
@@ -209,7 +206,10 @@ private:
     KWord::RunAroundSide m_runAroundSide;
     KWord::TextRunAround m_runAround;
     qreal m_runAroundDistance;
-    KoTextAnchor *m_anchor;
+    // The page number is only used during loading.
+    // It is set to the page number if the frame contains a page anchored frame.
+    // In all other cases it is set to -1.
+    int m_anchoredPageNumber;
 
     KWFrameSet *m_frameSet;
     KWOutlineShape *m_outline;
