@@ -21,13 +21,15 @@
 #include <kcmdlineargs.h>
 #include "KWAboutData.h"
 
-extern "C" KDE_EXPORT int kdemain( int argc, char **argv )
+extern "C" KDE_EXPORT int kdemain(int argc, char **argv)
 {
-    KCmdLineArgs::init( argc, argv, newKWordAboutData());
+    KAboutData * aboutData=newKWordAboutData();
+
+    KCmdLineArgs::init(argc, argv, aboutData);
 
     KCmdLineOptions options;
     options.add("+[file]", ki18n("File to open"));
-    KCmdLineArgs::addCmdLineOptions( options );
+    KCmdLineArgs::addCmdLineOptions(options);
 
     KoApplication app;
 
@@ -35,5 +37,7 @@ extern "C" KDE_EXPORT int kdemain( int argc, char **argv )
         return 1;
     app.exec();
 
+    delete (aboutData);
+
     return 0;
 }
