@@ -20,11 +20,12 @@
 #include "KoToolSelection.h"
 
 KoToolSelection::KoToolSelection(QObject *parent)
-    : QObject(parent)
+        : QObject(parent)
 {
 }
 
-KoToolSelection::~KoToolSelection() {
+KoToolSelection::~KoToolSelection()
+{
 }
 
 #include "KoToolSelection.moc"
