@@ -21,7 +21,7 @@
 #ifndef KOSHAPETRANSFORMCOMMAND_H
 #define KOSHAPETRANSFORMCOMMAND_H
 
-#include <flake_export.h>
+#include "flake_export.h"
 #include <QtGui/QUndoCommand>
 
 class KoShape;
@@ -43,7 +43,7 @@ public:
      * @see KoShape::transformation()
      * @see KoShape::setTransformation()
      */
-    KoShapeTransformCommand( const QList<KoShape*> &shapes, const QList<QMatrix> &oldState, const QList<QMatrix> &newState, QUndoCommand * parent = 0 );
+    KoShapeTransformCommand(const QList<KoShape*> &shapes, const QList<QMatrix> &oldState, const QList<QMatrix> &newState, QUndoCommand * parent = 0);
     ~KoShapeTransformCommand();
     /// redo the command
     void redo();
