@@ -25,15 +25,16 @@
 #include "KoPathPointMoveStrategy.h"
 #include "KoPathControlPointMoveStrategy.h"
 #include "KoPathConnectionPointStrategy.h"
+#include "KoSelection.h"
 #include "commands/KoPathPointTypeCommand.h"
 #include "KoParameterChangeStrategy.h"
-#include <KoParameterShape.h>
-#include <KoCanvasBase.h>
-#include <KoCanvasResourceProvider.h>
-#include <KoShapeManager.h>
-#include <KoConnectionShape.h>
-#include <KoViewConverter.h>
-#include <KoPointerEvent.h>
+#include "KoParameterShape.h"
+#include "KoCanvasBase.h"
+#include "KoResourceManager.h"
+#include "KoShapeManager.h"
+#include "KoConnectionShape.h"
+#include "KoViewConverter.h"
+#include "KoPointerEvent.h"
 #include <QtGui/QPainter>
 
 KoPathToolHandle::KoPathToolHandle(KoPathTool *tool)
@@ -45,7 +46,7 @@ KoPathToolHandle::~KoPathToolHandle()
 {
 }
 
-PointHandle::PointHandle(KoPathTool *tool, KoPathPoint *activePoint, KoPathPoint::KoPointType activePointType)
+PointHandle::PointHandle(KoPathTool *tool, KoPathPoint *activePoint, KoPathPoint::PointType activePointType)
         : KoPathToolHandle(tool)
         , m_activePoint(activePoint)
         , m_activePointType(activePointType)
@@ -60,10 +61,10 @@ void PointHandle::paint(QPainter &painter, const KoViewConverter &converter)
 
     KoPathToolSelection * selection = dynamic_cast<KoPathToolSelection*>(m_tool->selection());
 
-    KoPathPoint::KoPointType type = KoPathPoint::Node;
+    KoPathPoint::PointType type = KoPathPoint::Node;
     if (selection && selection->contains(m_activePoint))
         type = KoPathPoint::All;
-    int handleRadius = m_tool->canvas()->resourceProvider()->handleRadius();
+    int handleRadius = m_tool->canvas()->resourceManager()->handleRadius();
     m_activePoint->paint(painter, handleRadius, type);
     painter.restore();
 }
@@ -81,7 +82,7 @@ KoInteractionStrategy * PointHandle::handleMousePress(KoPointerEvent *event)
 {
     if ((event->button() & Qt::LeftButton) == 0)
         return 0;
-    if ((event->modifiers() & Qt::ShiftButton) == 0) { // no shift pressed.
+    if ((event->modifiers() & Qt::ShiftModifier) == 0) { // no shift pressed.
         KoPathToolSelection * selection = dynamic_cast<KoPathToolSelection*>(m_tool->selection());
 
         // control select adds/removes points to/from the selection
@@ -102,14 +103,14 @@ KoInteractionStrategy * PointHandle::handleMousePress(KoPointerEvent *event)
         // TODO remove canvas from call ?
         if (m_activePointType == KoPathPoint::Node) {
             QPointF startPoint = m_activePoint->parent()->shapeToDocument(m_activePoint->point());
-            return new KoPathPointMoveStrategy(m_tool, m_tool->canvas(), startPoint);
+            return new KoPathPointMoveStrategy(m_tool, startPoint);
         } else {
             KoPathShape * pathShape = m_activePoint->parent();
             KoPathPointData pd(pathShape, pathShape->pathPointIndex(m_activePoint));
-            return new KoPathControlPointMoveStrategy(m_tool, m_tool->canvas(), pd, m_activePointType, event->point);
+            return new KoPathControlPointMoveStrategy(m_tool, pd, m_activePointType, event->point);
         }
     } else {
-        KoPathPoint::KoPointProperties props = m_activePoint->properties();
+        KoPathPoint::PointProperties props = m_activePoint->properties();
         if (! m_activePoint->activeControlPoint1() || ! m_activePoint->activeControlPoint2())
             return 0;
 
@@ -140,7 +141,7 @@ KoPathPoint * PointHandle::activePoint() const
     return m_activePoint;
 }
 
-KoPathPoint::KoPointType PointHandle::activePointType() const
+KoPathPoint::PointType PointHandle::activePointType() const
 {
     return m_activePointType;
 }
@@ -157,7 +158,7 @@ void ParameterHandle::paint(QPainter &painter, const KoViewConverter &converter)
     painter.save();
     painter.setMatrix(m_parameterShape->absoluteTransformation(&converter) * painter.matrix());
 
-    int handleRadius = m_tool->canvas()->resourceProvider()->handleRadius();
+    int handleRadius = m_tool->canvas()->resourceManager()->handleRadius();
     m_parameterShape->paintHandle(painter, converter, m_handleId, handleRadius);
     painter.restore();
 }
@@ -173,7 +174,7 @@ KoInteractionStrategy * ParameterHandle::handleMousePress(KoPointerEvent *event)
         KoPathToolSelection * selection = dynamic_cast<KoPathToolSelection*>(m_tool->selection());
         if (selection)
             selection->clear();
-        return new KoParameterChangeStrategy(m_tool, m_tool->canvas(), m_parameterShape, m_handleId);
+        return new KoParameterChangeStrategy(m_tool, m_parameterShape, m_handleId);
     }
     return 0;
 }
@@ -198,7 +199,7 @@ KoInteractionStrategy * ConnectionHandle::handleMousePress(KoPointerEvent *event
         KoConnectionShape * shape = dynamic_cast<KoConnectionShape*>(m_parameterShape);
         if (! shape)
             return 0;
-        return new KoPathConnectionPointStrategy(m_tool, m_tool->canvas(), shape, m_handleId);
+        return new KoPathConnectionPointStrategy(m_tool, shape, m_handleId);
     }
     return 0;
 }
