@@ -4,7 +4,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (  at your option ) any later version.
+ * version 2 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,7 +20,12 @@
 #include "KoPAViewMode.h"
 
 #include "KoPACanvas.h"
+#include "KoPAPageBase.h"
 #include "KoPAView.h"
+#include <KoCanvasController.h>
+#include <KoPageLayout.h>
+
+#include <QCloseEvent>
 
 KoPAViewMode::KoPAViewMode( KoPAView * view, KoPACanvas * canvas )
 : m_canvas( canvas )
@@ -51,6 +56,11 @@ bool KoPAViewMode::masterMode()
 void KoPAViewMode::activate( KoPAViewMode * previousViewMode )
 {
     Q_UNUSED( previousViewMode );
+    m_canvas->updateSize();
+    m_view->updateActivePage( m_view->activePage() );
+    // this is done to set the preferred center
+    m_canvas->canvasController()->setCanvasMode( KoCanvasController::Centered );
+    m_canvas->canvasController()->recenterPreferred();
 }
 
 void KoPAViewMode::deactivate()
@@ -74,7 +84,7 @@ KoViewConverter * KoPAViewMode::viewConverter( KoPACanvas * canvas )
 
 void KoPAViewMode::updateActivePage( KoPAPageBase *page )
 {
-    m_view->updateActivePage( page );
+    m_view->doUpdateActivePage( page );
 }
 
 void KoPAViewMode::addShape( KoShape *shape )
@@ -87,4 +97,27 @@ void KoPAViewMode::removeShape( KoShape *shape )
     Q_UNUSED( shape );
 }
 
-#include "KoPAViewMode.moc"
+const KoPageLayout &KoPAViewMode::activePageLayout() const
+{
+    return m_view->activePage()->pageLayout();
+}
+
+void KoPAViewMode::changePageLayout( const KoPageLayout &pageLayout, bool applyToDocument, QUndoCommand *parent )
+{
+    Q_UNUSED( pageLayout );
+    Q_UNUSED( applyToDocument );
+    Q_UNUSED( parent );
+}
+
+QPointF KoPAViewMode::origin()
+{
+    return m_origin;
+}
+ 
+void KoPAViewMode::setOrigin(const QPointF &o)
+{
+    m_origin = o;
+}
+
+#include <KoPAViewMode.moc>
+
