@@ -86,7 +86,7 @@ void KoRgbU8CompositeOp::composite(quint8 *dst, qint32 dstRowStride,
     else if (id() == COMPOSITE_ADD) {
         compositeAdd(m_pixelSize, dst, dstRowStride, src, srcRowStride, rows, cols, opacity, channelFlags);
     }
-    else if (id() == COMPOSITE_SUBTRACT) {
+    else if (id() == COMPOSITE_SUBSTRACT) {
         compositeSubtract(m_pixelSize, dst, dstRowStride, src, srcRowStride, rows, cols, opacity, channelFlags);
     }
     else if (id() == COMPOSITE_DIFF) {
@@ -394,7 +394,7 @@ void KoRgbU8CompositeOp::compositeDivide(quint8 *dstRowStart, qint32 dstRowStrid
                              quint8 srcColor = src[channel];
                              quint8 dstColor = dst[channel];
 
-                             srcColor = qMin((dstColor * (UINT8_MAX + 1u) + (srcColor / 2u)) / (1u + srcColor), UINT8_MAX);
+                             srcColor = qMin((dstColor * (UINT8_MAX + 1u) + (srcColor / 2u)) / (1u + srcColor), (uint)UINT8_MAX);
 
                              quint8 newColor = UINT8_BLEND(srcColor, dstColor, srcBlend);
 
