@@ -22,18 +22,25 @@
 
 #include <QtTest/QtTest>
 
-typedef QPair< QString, QString> pStrStr;
+struct ModelDepthProfile {
+    ModelDepthProfile(const QString& _model, const QString& _depth, const QString& _profile)
+            : model(_model), depth(_depth), profile(_profile) {
+    }
+    QString model;
+    QString depth;
+    QString profile;
+};
 
 class TestColorConversionSystem : public QObject
 {
-        Q_OBJECT
-    public:
-        TestColorConversionSystem();
-    private slots:
-        void testConnections();
-        void testGoodConnections();
-    private:
-        QList< pStrStr > listModels;
+    Q_OBJECT
+public:
+    TestColorConversionSystem();
+private slots:
+    void testConnections();
+    void testGoodConnections();
+private:
+    QList< ModelDepthProfile > listModels;
 };
 
 #endif
